@@ -9,7 +9,7 @@ class TableColor():
     def __init__(self, DataFrame):
                 
         self.df = DataFrame
-		return lightgrey(self.df)
+		self.lightgrey()
     
     def lightblue(self):
     
